AnsiColor class

This class handles colorizing of terminal output.

Constructors

AnsiColor({int? backgroundColor, int? foregroundColor, bool italic = false})

Properties

backgroundColor → int?
final
color → bool
no setter
foregroundColor → int?
final
hashCode → int
The hash code for this object.
no setterinherited
italic → bool
final
resetBackground → String
Defaults the terminal's background color without altering the foreground.
no setter
resetForeground → String
Defaults the terminal's foreground color without altering the background.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String msg) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Colors and styles are taken from: https://en.wikipedia.org/wiki/ANSI_escape_code
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

grey(double level) → int

Constants

ansiDefault → const String
Reset all colors and options for current SGRs to terminal defaults.
ansiEsc → const String
ANSI Control Sequence Introducer, signals the terminal for new settings.