LogLevel class

Level class. Name is used printed out to console, and priority is used as level to find out severity of the log.

priority can go from 1 - 99 inclusive. 0 is reserved for All and 100 is reserved for Off

Constructors

LogLevel(String name, int priority)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
priority → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

all → const LogLevel
Reserved levels
debug → const LogLevel
Default levels
error → const LogLevel
info → const LogLevel
off → const LogLevel
values → const List<LogLevel>
warning → const LogLevel