LogRecord class

This is sent to the LogPrinter and there printer can choose what and how to show it

Constructors

LogRecord(LogLevel level, String message, String loggerName, [Object? error, StackTrace? stackTrace, Zone? zone, Object? object, Frame? callerFrame])

Properties

callerFrame → Frame?
final
error → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
level → LogLevel
final
loggerName → String
final
message → String
final
object → Object?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber → int
final
stackTrace → StackTrace?
final
time → DateTime
final
zone → Zone?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited